@@ -1,17 +1,25 @@
 package Pod::Elemental::Document;
-{
-  $Pod::Elemental::Document::VERSION = '0.102363';
-}
+# ABSTRACT: a pod document
+$Pod::Elemental::Document::VERSION = '0.103002';
 use Moose;
 with 'Pod::Elemental::Node';
-# ABSTRACT: a pod document
 
+use Class::Load ();
 use Moose::Autobox;
 use namespace::autoclean;
 
 use Pod::Elemental::Element::Generic::Blank;
 use String::RewritePrefix;
 
+#pod =head1 OVERVIEW
+#pod
+#pod Pod::Elemental::Document is a container for Pod documents.  It performs
+#pod L<Pod::Elemental::Node> but I<not> L<Pod::Elemental::Paragraph>.
+#pod
+#pod Documents are used almost exclusively to give a small amount of behavior to
+#pod arrayrefs of paragraphs, and have few methods of their own.
+#pod
+#pod =cut
 
 sub _expand_name {
   my ($self, $name) = @_;
@@ -28,10 +36,12 @@ sub _expand_name {
 sub as_pod_string {
   my ($self) = @_;
 
-  join q{},
-    "=pod\n\n",
-    $self->children->map(sub { $_->as_pod_string })->flatten,
-    "=cut\n";
+  my $str = join q{}, $self->children->map(sub { $_->as_pod_string })->flatten;
+
+  $str = "=pod\n\n$str" unless $str =~ /\A=pod\n/;
+  $str .= "=cut\n" unless $str =~ /=cut\n+\z/;
+
+  return $str;
 }
 
 sub as_debug_string {
@@ -45,19 +55,19 @@ sub _elem_from_lol_entry {
 
   if (! defined $type) {
     my $n_class = $self->_expand_name($arg->{class} || 'Generic::Text');
-    Class::MOP::load_class($n_class);
+    Class::Load::load_class($n_class);
     return $n_class->new({ content => "$content\n" });
   } elsif ($type =~ /\A=(\w+)\z/) {
     my $command = $1;
     my $n_class = $self->_expand_name($arg->{class} || 'Generic::Command');
-    Class::MOP::load_class($n_class);
+    Class::Load::load_class($n_class);
     return $n_class->new({
       command => $command,
       content => "$content\n"
     });
   } else {
     my $n_class = $self->_expand_name($arg->{class} || 'Pod5::Region');
-    Class::MOP::load_class($n_class);
+    Class::Load::load_class($n_class);
 
     my @children;
 
@@ -101,19 +111,23 @@ sub new_from_lol {
   return $self;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Pod::Elemental::Document - a pod document
 
 =head1 VERSION
 
-version 0.102363
+version 0.103002
 
 =head1 OVERVIEW
 
@@ -129,7 +143,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2014 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
