@@ -1,16 +1,24 @@
 package Pod::Elemental::Element::Generic::Blank;
-{
-  $Pod::Elemental::Element::Generic::Blank::VERSION = '0.102364';
-}
+# ABSTRACT: a series of blank lines
+$Pod::Elemental::Element::Generic::Blank::VERSION = '0.103002';
 use Moose;
 with 'Pod::Elemental::Flat';
-# ABSTRACT: a series of blank lines
 
+#pod =head1 OVERVIEW
+#pod
+#pod Generic::Blank elements represent vertical whitespace in a Pod document.  For
+#pod the most part, these are meant to be placeholders until made unnecessary by the
+#pod Pod5 transformer.  Most end-users will never need to worry about these
+#pod elements.
+#pod
+#pod =cut
 
 use namespace::autoclean;
 
 sub as_debug_string { '|' }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -25,7 +33,7 @@ Pod::Elemental::Element::Generic::Blank - a series of blank lines
 
 =head1 VERSION
 
-version 0.102364
+version 0.103002
 
 =head1 OVERVIEW
 
@@ -40,7 +48,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2014 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
