@@ -1,13 +1,21 @@
 package Pod::Elemental::Element::Generic::Text;
-{
-  $Pod::Elemental::Element::Generic::Text::VERSION = '0.102364';
-}
+# ABSTRACT: a Pod text or verbatim element
+$Pod::Elemental::Element::Generic::Text::VERSION = '0.103002';
 use Moose;
 with 'Pod::Elemental::Flat';
-# ABSTRACT: a Pod text or verbatim element
 
 use namespace::autoclean;
 
+#pod =head1 OVERVIEW
+#pod
+#pod Generic::Text elements represent text paragraphs found in raw Pod.  They are
+#pod likely to be fed to a Pod5 translator and converted to ordinary, verbatim, or
+#pod data paragraphs in that dialect.  Otherwise, Generic::Text paragraphs are
+#pod simple flat paragraphs.
+#pod
+#pod =cut
+
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -23,7 +31,7 @@ Pod::Elemental::Element::Generic::Text - a Pod text or verbatim element
 
 =head1 VERSION
 
-version 0.102364
+version 0.103002
 
 =head1 OVERVIEW
 
@@ -38,7 +46,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2014 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
