@@ -1,12 +1,10 @@
 package Pod::Elemental::Element::Nested;
-{
-  $Pod::Elemental::Element::Nested::VERSION = '0.102364';
-}
+# ABSTRACT: an element that is a command and a node
+$Pod::Elemental::Element::Nested::VERSION = '0.103002';
 use Moose;
 extends 'Pod::Elemental::Element::Generic::Command';
 with 'Pod::Elemental::Node';
 with 'Pod::Elemental::Autochomp';
-# ABSTRACT: an element that is a command and a node
 
 use namespace::autoclean;
 
@@ -17,6 +15,20 @@ use Pod::Elemental::Types qw(ChompedString);
 has '+content' => (coerce => 1, isa => ChompedString);
 # END   Autochomp Replacement
 
+#pod =head1 WARNING
+#pod
+#pod This class is somewhat sketchy and may be refactored somewhat in the future,
+#pod specifically to refactor its similarities to
+#pod L<Pod::Elemental::Element::Pod5::Region>.
+#pod
+#pod =head1 OVERVIEW
+#pod
+#pod A Nested element is a Generic::Command element that is also a node.
+#pod
+#pod It's used by the nester transformer to produce commands with children, to make
+#pod documents seem more structured for easy manipulation.
+#pod
+#pod =cut
 
 override as_pod_string => sub {
   my ($self) = @_;
@@ -32,6 +44,8 @@ override as_pod_string => sub {
   return $string;
 };
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -46,7 +60,7 @@ Pod::Elemental::Element::Nested - an element that is a command and a node
 
 =head1 VERSION
 
-version 0.102364
+version 0.103002
 
 =head1 OVERVIEW
 
@@ -67,7 +81,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2014 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
