@@ -1,9 +1,7 @@
 package Pod::Elemental::Element::Pod5::Command;
-{
-  $Pod::Elemental::Element::Pod5::Command::VERSION = '0.102364';
-}
-use Moose;
 # ABSTRACT: a Pod5 =command element
+$Pod::Elemental::Element::Pod5::Command::VERSION = '0.103002';
+use Moose;
 
 extends 'Pod::Elemental::Element::Generic::Command';
 with    'Pod::Elemental::Autoblank';
@@ -15,9 +13,19 @@ has '+content' => (
   isa    => ChompedString,
 );
 
+#pod =head1 OVERVIEW
+#pod
+#pod Pod5::Command elements are identical to
+#pod L<Generic::Command|Pod::Elemental::Element::Generic::Command> elements, except
+#pod that they incorporate L<Pod::Elemental::Autoblank>.  They represent command
+#pod paragraphs in a Pod5 document.
+#pod
+#pod =cut
 
 use namespace::autoclean;
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -32,7 +40,7 @@ Pod::Elemental::Element::Pod5::Command - a Pod5 =command element
 
 =head1 VERSION
 
-version 0.102364
+version 0.103002
 
 =head1 OVERVIEW
 
@@ -47,7 +55,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2014 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
