@@ -1,21 +1,27 @@
 package Pod::Elemental::Element::Pod5::Ordinary;
-{
-  $Pod::Elemental::Element::Pod5::Ordinary::VERSION = '0.102364';
-}
+# ABSTRACT: a Pod5 ordinary text paragraph
+$Pod::Elemental::Element::Pod5::Ordinary::VERSION = '0.103002';
 use Moose;
 extends 'Pod::Elemental::Element::Generic::Text';
 with    'Pod::Elemental::Autoblank';
 with    'Pod::Elemental::Autochomp';
-# ABSTRACT: a Pod5 ordinary text paragraph
 
 # BEGIN Autochomp Replacement
 use Pod::Elemental::Types qw(ChompedString);
 has '+content' => (coerce => 1, isa => ChompedString);
 # END   Autochomp Replacement
 
+#pod =head1 OVERVIEW
+#pod
+#pod A Pod5::Ordinary element represents a plain old paragraph of text found in a
+#pod Pod document that's gone through the Pod5 translator.
+#pod
+#pod =cut
 
 use namespace::autoclean;
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -30,7 +36,7 @@ Pod::Elemental::Element::Pod5::Ordinary - a Pod5 ordinary text paragraph
 
 =head1 VERSION
 
-version 0.102364
+version 0.103002
 
 =head1 OVERVIEW
 
@@ -43,7 +49,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2014 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
