@@ -1,11 +1,19 @@
 package Pod::Elemental::Objectifier;
-{
-  $Pod::Elemental::Objectifier::VERSION = '0.102364';
-}
+# ABSTRACT: it turns a Pod::Eventual event stream into objects
+$Pod::Elemental::Objectifier::VERSION = '0.103002';
 use Moose;
 use Moose::Autobox;
-# ABSTRACT: it turns a Pod::Eventual event stream into objects
 
+#pod =head1 OVERVIEW
+#pod
+#pod An objectifier is responsible for taking the events produced by
+#pod L<Pod::Eventual|Pod::Eventual> and converting them into objects that perform
+#pod the Pod::Elemental::Paragraph role.
+#pod
+#pod In general, it does this by producing a sequence of element objects in the
+#pod Pod::Elemental::Element::Generic namespace.
+#pod
+#pod =cut
 
 use namespace::autoclean;
 
@@ -14,6 +22,14 @@ use Pod::Elemental::Element::Generic::Command;
 use Pod::Elemental::Element::Generic::Nonpod;
 use Pod::Elemental::Element::Generic::Text;
 
+#pod =method objectify_events
+#pod
+#pod   my $elements = $objectifier->objectify_events(\@events);
+#pod
+#pod Given an arrayref of Pod events, this method returns an arrayref of objects
+#pod formed from the event stream.
+#pod
+#pod =cut
 
 sub objectify_events {
   my ($self, $events) = @_;
@@ -34,6 +50,11 @@ sub objectify_events {
 }
 
 
+#pod =method element_class_for_event
+#pod
+#pod This method returns the name of the class to be used for the given event.
+#pod
+#pod =cut
 
 sub __class_for {
   return {
@@ -54,6 +75,8 @@ sub element_class_for_event {
   return $class_for->{ $t };
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -68,7 +91,7 @@ Pod::Elemental::Objectifier - it turns a Pod::Eventual event stream into objects
 
 =head1 VERSION
 
-version 0.102364
+version 0.103002
 
 =head1 OVERVIEW
 
@@ -98,7 +121,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2014 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
