@@ -1,11 +1,49 @@
 package Pod::Elemental::Transformer::Pod5;
-{
-  $Pod::Elemental::Transformer::Pod5::VERSION = '0.102364';
-}
+# ABSTRACT: the default, minimal semantics of Perl5's pod element hierarchy
+$Pod::Elemental::Transformer::Pod5::VERSION = '0.103002';
 use Moose;
 with 'Pod::Elemental::Transformer';
-# ABSTRACT: the default, minimal semantics of Perl5's pod element hierarchy
 
+#pod =head1 SYNOPSIS
+#pod
+#pod   Pod::Elemental::Transformer::Pod5->new->transform_node($pod_elem_document);
+#pod
+#pod ...and that's it.
+#pod
+#pod =head1 OVERVIEW
+#pod
+#pod The Pod5 transformer is meant to be used to convert the result of a "stock"
+#pod Pod::Elemental::Document into something simpler to work with.  It assumes that
+#pod the document conforms more or less to the convetions laid out in L<perlpod> and
+#pod L<perlpodspec>.  It is not very strict, and makes very few assumptions,
+#pod described here:
+#pod
+#pod =over 4
+#pod
+#pod =item * =begin/=end and =for enclose or produce regions within the document
+#pod
+#pod =item * regions are associated with format names; format names that begin with a colon enclose more pod-like content
+#pod
+#pod =item * regions nest strictly; all inner regions must end before outer regions
+#pod
+#pod =item * paragraphs in non-pod regions are "data" paragraphs
+#pod
+#pod =item * non-data paragraphs that start with spaces are "verbatim" paragraphs
+#pod
+#pod =item * groups of data or verbatim paragraphs can be consolodated
+#pod
+#pod =back
+#pod
+#pod Further, all elements are replaced with equivalent elements that perform the
+#pod L<Pod::Elemental::Autoblank> role, so all "blank" events can be removed form
+#pod the tree and ignored.
+#pod
+#pod =head1 CONFIGURATION
+#pod
+#pod None.  For now, it just does the same thing every time with no configuration or
+#pod options.
+#pod
+#pod =cut
 
 use Moose::Autobox 0.10;
 
@@ -249,6 +287,8 @@ sub transform_node {
   return $node;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -263,7 +303,7 @@ Pod::Elemental::Transformer::Pod5 - the default, minimal semantics of Perl5's po
 
 =head1 VERSION
 
-version 0.102364
+version 0.103002
 
 =head1 SYNOPSIS
 
@@ -310,7 +350,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2014 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
